;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "erlang-ts" "20251021.838"
  "Major modes for editing Erlang."
  '((emacs  "29.2")
    (erlang "27.2"))
  :url "https://github.com/erlang/emacs-erlang-ts"
  :commit "a778abd435377ce57db3fd73e122982609a01f6f"
  :revdesc "a778abd43537"
  :keywords '("erlang" "languages" "treesitter"))
